"use strict";

function ResponsiveCellHeaders(elmID) {
  try {
    var THarray = [];
    var table = document.getElementById(elmID);
    var ths = table.getElementsByTagName("th");

    for (var i = 0; i < ths.length; i++) {
      var headingText = ths[i].innerHTML;
      THarray.push(headingText);
    }

    var styleElm = document.createElement("style"),
        styleSheet;
    document.head.appendChild(styleElm);
    styleSheet = styleElm.sheet;

    for (var i = 0; i < THarray.length; i++) {
      styleSheet.insertRule("#" + elmID + " td:nth-child(" + (i + 1) + ')::before {content:"' + THarray[i] + ': ";}', styleSheet.cssRules.length);
    }
  } catch (e) {
    console.log("ResponsiveCellHeaders(): " + e);
  }
}

ResponsiveCellHeaders("Books"); // https://adrianroselli.com/2018/02/tables-css-display-properties-and-aria.html
// https://adrianroselli.com/2018/05/functions-to-add-aria-to-tables-and-lists.html

function AddTableARIA() {
  try {
    var allTables = document.querySelectorAll('table');

    for (var i = 0; i < allTables.length; i++) {
      allTables[i].setAttribute('role', 'table');
    }

    var allRowGroups = document.querySelectorAll('thead, tbody, tfoot');

    for (var i = 0; i < allRowGroups.length; i++) {
      allRowGroups[i].setAttribute('role', 'rowgroup');
    }

    var allRows = document.querySelectorAll('tr');

    for (var i = 0; i < allRows.length; i++) {
      allRows[i].setAttribute('role', 'row');
    }

    var allCells = document.querySelectorAll('td');

    for (var i = 0; i < allCells.length; i++) {
      allCells[i].setAttribute('role', 'cell');
    }

    var allHeaders = document.querySelectorAll('th');

    for (var i = 0; i < allHeaders.length; i++) {
      allHeaders[i].setAttribute('role', 'columnheader');
    } // this accounts for scoped row headers


    var allRowHeaders = document.querySelectorAll('th[scope=row]');

    for (var i = 0; i < allRowHeaders.length; i++) {
      allRowHeaders[i].setAttribute('role', 'rowheader');
    } // caption role not needed as it is not a real role and
    // browsers do not dump their own role with display block

  } catch (e) {
    console.log("AddTableARIA(): " + e);
  }
}

AddTableARIA();
/******************************************************************************************************
 *  inert attribute POLYFILL                                                                          *
 *  SOURCE: https://cdn.rawgit.com/GoogleChrome/inert-polyfill/v0.1.0/inert-polyfill.min.js           *
 * ****************************************************************************************************/

window.addEventListener("load", function () {
  function h(a, b, c) {
    if (0 > b) {
      if (a.previousElementSibling) {
        for (a = a.previousElementSibling; a.lastElementChild;) {
          a = a.lastElementChild;
        }

        return a;
      }

      return a.parentElement;
    }

    if (a != c && a.firstElementChild) return a.firstElementChild;

    for (; null != a;) {
      if (a.nextElementSibling) return a.nextElementSibling;
      a = a.parentElement;
    }

    return null;
  }

  function g(a) {
    for (; a && a !== document.documentElement;) {
      if (a.hasAttribute("inert")) return a;
      a = a.parentElement;
    }

    return null;
  }

  (function (a) {
    var b = document.createElement("style");
    b.type = "text/css";
    b.styleSheet ? b.styleSheet.cssText = a : b.appendChild(document.createTextNode(a));
    document.body.appendChild(b);
  })("/*[inert]*/[inert]{position:relative!important;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;pointer-events:none}[inert]::before{content:'';display:block;position:absolute;top:0;left:0;right:0;bottom:0}");

  var c = 0;
  document.addEventListener("keydown", function (a) {
    c = 9 === a.keyCode ? a.shiftKey ? -1 : 1 : 0;
  });
  document.addEventListener("mousedown", function () {
    c = 0;
  });
  document.body.addEventListener("focus", function (a) {
    var b = a.target,
        f = g(b);

    if (f) {
      if (document.hasFocus() && 0 !== c) {
        var d = document.activeElement,
            e = new KeyboardEvent("keydown", {
          keyCode: 9,
          which: 9,
          key: "Tab",
          code: "Tab",
          keyIdentifier: "U+0009",
          shiftKey: !!(0 > c),
          bubbles: !0
        });
        Object.defineProperty(e, "keyCode", {
          value: 9
        });
        document.activeElement.dispatchEvent(e);
        if (d != document.activeElement) return;

        for (d = f;;) {
          d = h(d, c, f);
          if (!d) break;

          a: {
            e = b;

            if (!(0 > d.tabIndex) && (d.focus(), document.activeElement !== e)) {
              e = !0;
              break a;
            }

            e = !1;
          }

          if (e) return;
        }
      }

      b.blur();
      a.preventDefault();
      a.stopPropagation();
    }
  }, !0);
  document.addEventListener("click", function (a) {
    g(a.target) && (a.preventDefault(), a.stopPropagation());
  }, !0);
});
/******************************************************************************************************
 *  DOWNLOAD ATTRIBUTE POLYFILL                                                                       *
 *  SOURCE: https://github.com/jelmerdemaat/dwnld-attr-polyfill/blob/master/src/download-polyfill.js  *
 * ****************************************************************************************************/

var downloadAttributeSupport = ('download' in document.createElement('a'));
var msSaveBlob = typeof window.navigator.msSaveBlob !== 'undefined';

if (!downloadAttributeSupport && msSaveBlob) {
  document.addEventListener('click', function (evt) {
    var target = evt.target;
    var tagName = target.tagName;

    if (tagName === 'A' && target.hasAttribute('download')) {
      evt.preventDefault();
      var href = target.href;
      var fileName = new URL(href).pathname.split('/').pop();
      var xhr = new XMLHttpRequest();
      xhr.open('GET', href);
      xhr.responseType = 'blob';

      xhr.onreadystatechange = function () {
        if (xhr.readyState !== 4) {
          return;
        }

        if (xhr.status === 200) {
          window.navigator.msSaveBlob(xhr.response, fileName);
        } else {
          console.error('download-attribute-polyfill:', xhr.status, xhr.statusText);
        }
      };

      xhr.send();
    }
  });
}
/************************************************************************************************
 *
 * This function calculates the width of the browser scrollbar,
 * and then stores this value in the CSS variable --scrollbar
 * source: https://codepen.io/Mamboleoo/post/scrollbars-and-css-custom-properties#my-solution-5
 *
 *************************************************************************************************/


(function () {
  var getScrollbarWidth = function getScrollbarWidth() {
    // Create a temporary div container and append it into the body
    var container = document.createElement('div'); // Append the container in the body

    document.body.appendChild(container); // Force scrollbar on the container

    container.style.overflow = 'scroll'; // Add ad fake div inside the container

    var inner = document.createElement('div');
    container.appendChild(inner); // Calculate the width based on the container width minus its child width

    var width = container.offsetWidth - inner.offsetWidth; // Remove the container from the body

    document.body.removeChild(container);
    return width;
  }; // Get the scrollbar dimension


  var scrollbarWidth = getScrollbarWidth(); // Set a custom property with the value we calculated

  document.documentElement.style.setProperty('--scrollbar', "".concat(scrollbarWidth, "px"));
})();
/*
 * Collapsible panels
 */


var disclosureWidget = function disclosureWidget(el) {
  this.toggle = el;
  this.panel = this.getNextSibling(el, '[data-panel]');
  this.init();
};

disclosureWidget.prototype.init = function () {
  var self = this;
  var ariaState = this.toggle.getAttribute("aria-expanded");
  var startState = this.toggle.getAttribute("data-start-state");
  var mobileOnly = this.toggle.getAttribute('data-mobile-only');

  if (mobileOnly) {
    var handleViewportChange = function handleViewportChange(e) {
      if (e.matches) {
        self.toggle.removeAttribute('hidden');

        if (startState === "open") {
          self.toggle.setAttribute("aria-expanded", "true");
          self.openPanel();
        } else {
          self.toggle.setAttribute("aria-expanded", "false");
          self.closePanel();
        }
      } else {
        self.toggle.setAttribute('hidden', '');
        self.toggle.setAttribute("aria-expanded", "true");
        self.openPanel();
      }
    };

    var mediaQuery = window.matchMedia('(max-width: 880px)');
    mediaQuery.addListener(handleViewportChange);
    handleViewportChange(mediaQuery);
  } else {
    if (ariaState === null) {
      if (startState === "open") this.toggle.setAttribute("aria-expanded", "open");else this.toggle.setAttribute("aria-expanded", "false");
    }

    if (startState === "open") this.toggle.setAttribute("aria-expanded", "true");else {
      this.toggle.setAttribute("aria-expanded", "false");
      this.closePanel();
    }
  }

  this.toggle.addEventListener("click", function () {
    var currentState = self.toggle.getAttribute("aria-expanded"),
        newState = currentState === "true" ? "false" : "true";
    self.toggle.setAttribute("aria-expanded", newState);

    if (newState === 'true') {
      self.openPanel(); // window.addEventListener('resize', this.updatePanelHeight.bind(this));
    } else {
      self.closePanel();
      self.toggle.focus();
    }
  });
}; // disclosureWidget.prototype.updatePanelHeight = function() {
//     var self = this;
//     this.panelHeight = this.panel.offsetHeight + 'px';
//     this.panel.style.height = this.panelHeight;
//     console.log(self.panelHeight);
// }


disclosureWidget.prototype.getNextSibling = function (elem, selector) {
  var sibling = elem.nextElementSibling;

  while (sibling) {
    if (sibling.matches(selector)) return sibling;
    sibling = sibling.nextElementSibling;
  }
};

disclosureWidget.prototype.closePanel = function () {
  this.panel.setAttribute('hidden', '');
  this.toggle.setAttribute("aria-expanded", 'false');
  open = false;
};

disclosureWidget.prototype.openPanel = function () {
  open = true;
  this.panel.removeAttribute('hidden');
};

var dw_toggles = document.querySelectorAll('[data-toggle]');
var dws = [];

for (var i = 0; i < dw_toggles.length; i++) {
  dws[i] = new disclosureWidget(dw_toggles[i]); // dws[i].init();
} // console.log the currently focused element
// document.addEventListener('focusin', function() {
//     console.log('focused: ', document.activeElement)
// }, true);

/*! matchMedia() polyfill - Test a CSS media type/query in JS. Authors & copyright (c) 2012: Scott Jehl, Paul Irish, Nicholas Zakas, David Knight. MIT license */


window.matchMedia || (window.matchMedia = function () {
  "use strict"; // For browsers that support matchMedium api such as IE 9 and webkit

  var styleMedia = window.styleMedia || window.media; // For those that don't support matchMedium

  if (!styleMedia) {
    var style = document.createElement('style'),
        script = document.getElementsByTagName('script')[0],
        info = null;
    style.type = 'text/css';
    style.id = 'matchmediajs-test';

    if (!script) {
      document.head.appendChild(style);
    } else {
      script.parentNode.insertBefore(style, script);
    } // 'style.currentStyle' is used by IE <= 8 and 'window.getComputedStyle' for all other browsers


    info = 'getComputedStyle' in window && window.getComputedStyle(style, null) || style.currentStyle;
    styleMedia = {
      matchMedium: function matchMedium(media) {
        var text = '@media ' + media + '{ #matchmediajs-test { width: 1px; } }'; // 'style.styleSheet' is used by IE <= 8 and 'style.textContent' for all other browsers

        if (style.styleSheet) {
          style.styleSheet.cssText = text;
        } else {
          style.textContent = text;
        } // Test if media query is true or false


        return info.width === '1px';
      }
    };
  }

  return function (media) {
    return {
      matches: styleMedia.matchMedium(media || 'all'),
      media: media || 'all'
    };
  };
}());